splearn package
===============

Subpackages
-----------

.. toctree::

    splearn.datasets

Submodules
----------

splearn.automaton module
------------------------

.. automodule:: splearn.automaton
    :members:
    :undoc-members:
    :show-inheritance:

splearn.hankel module
---------------------

.. automodule:: splearn.hankel
    :members:
    :undoc-members:
    :show-inheritance:

splearn.serializer module
-------------------------

.. automodule:: splearn.serializer
    :members:
    :undoc-members:
    :show-inheritance:

splearn.spectral module
-----------------------

.. automodule:: splearn.spectral
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: splearn
    :members:
    :undoc-members:
    :show-inheritance:
